@@ -1,5 +1,7 @@
-#' @title The adjusted inverse hyperbolic sine confidence interval for the ratio of probabilities
-#' @description The adjusted inverse hyperbolic sine confidence interval for the ratio of probabilities
+#' @title The adjusted inverse hyperbolic sine confidence interval for the
+#' ratio of probabilities
+#' @description The adjusted inverse hyperbolic sine confidence interval for
+#' the ratio of probabilities
 #' @description Described in Chapter 4 "The 2x2 Table"
 #' @param n the observed counts (a 2x2 matrix)
 #' @param psi1 pseudo-frequency
@@ -7,17 +9,23 @@
 #' @param psi3 pseudo-frequency
 #' @param psi4 pseudo-frequency
 #' @param alpha the nominal level, e.g. 0.05 for 95% CIs
-#' @param printresults display results
-#' @return A data frame containing lower, upper and point estimates of the statistic
+#' @return An object of the [contingencytables_result] class,
+#' basically a subclass of [base::list()]. Use the [utils::str()] function
+#' to see the specific elements returned.
 #' @examples
-#' # An RCT of high vs standard dose of epinephrine (Perondi et al., 2004):
-#' n <- matrix(c(7, 27, 1, 33), nrow = 2, byrow = TRUE)
-#' Adjusted_inv_sinh_CI_ratio_2x2(n)
-#' # The association between CHRNA4 genotype and XFS (Ritland et al., 2007):
-#' n <- matrix(c(0, 16, 15, 57), nrow = 2, byrow = TRUE)
-#' Adjusted_inv_sinh_CI_ratio_2x2(n)
+#' Adjusted_inv_sinh_CI_ratio_2x2(perondi_2004)
+#' Adjusted_inv_sinh_CI_ratio_2x2(ritland_2007)
 #' @export
-Adjusted_inv_sinh_CI_ratio_2x2 <- function(n, psi1 = 0, psi2 = 0, psi3 = 0, psi4 = 1, alpha = 0.05, printresults = TRUE) {
+Adjusted_inv_sinh_CI_ratio_2x2 <- function(
+  n, psi1 = 0, psi2 = 0, psi3 = 0, psi4 = 1, alpha = 0.05
+) {
+  validateArguments(
+    x = mget(ls()),
+    types = c(
+      n = "counts", psi1 = "skip", psi2 = "skip", psi3 = "skip", psi4 = "skip",
+      alpha = "probability"
+    )
+  )
   n1p <- n[1, 1] + n[1, 2]
   n2p <- n[2, 1] + n[2, 2]
 
@@ -49,15 +57,16 @@ Adjusted_inv_sinh_CI_ratio_2x2 <- function(n, psi1 = 0, psi2 = 0, psi3 = 0, psi4
     L <- (n[1, 1] / n1p) / ((z^2) / n2p)
   }
 
-  if (printresults) {
-    print(
-      sprintf(
-        "The adjusted inverse sinh CI: estimate = %6.4f (%g%% CI %6.4f to %6.4f)",
-        estimate, 100 * (1 - alpha), L, U
-      ),
-      quote = FALSE
+  # Output
+  printresults <- function() {
+    my_sprintf_cat(
+      "The adjusted inverse sinh CI: estimate = %6.4f (%g%% CI %6.4f to %6.4f)",
+      estimate, 100 * (1 - alpha), L, U
     )
   }
-  res <- data.frame(lower = L, upper = U, estimate = estimate)
-  invisible(res)
+  return(
+    contingencytables_result(
+      list(lower = L, upper = U, estimate = estimate), printresults
+    )
+  )
 }
