@@ -3,14 +3,14 @@
 #' @description Described in Chapter 7 "The rxc Table"
 #' @param n the observed counts (an rx2 vector)
 #' @param alpha the nominal level, e.g. 0.05 for 95% CIs
-#' @param printresults display results (FALSE = no, TRUE = yes)
-#' @return A list containing lower, upper and point estimates of the statistic
+#' @return An object of the [contingencytables_result] class,
+#' basically a subclass of [base::list()]. Use the [utils::str()] function
+#' to see the specific elements returned.
 #' @examples
-#' # Example: Treatment for ear infection
-#' n <- rbind(c(40, 25), c(54, 7), c(63, 10))
-#' Bonferroni_type_CIs_rxc(n)
+#' Bonferroni_type_CIs_rxc(table_7.3)
 #' @export
-Bonferroni_type_CIs_rxc <- function(n, alpha = 0.05, printresults = TRUE) {
+Bonferroni_type_CIs_rxc <- function(n, alpha = 0.05) {
+  validateArguments(mget(ls()))
   r <- nrow(n)
   nip <- apply(n, 1, sum)
   C <- r * (r - 1) / 2
@@ -39,16 +39,21 @@ Bonferroni_type_CIs_rxc <- function(n, alpha = 0.05, printresults = TRUE) {
     }
   }
 
-  if (printresults) {
-    print(sprintf("The Bonferroni-type simultaneous intervals"), quote = FALSE)
+  # Output
+  printresults <- function() {
+    my_sprintf_cat("The Bonferroni-type simultaneous intervals\n")
     k <- 0
     for (i in 1:r) {
       for (j in min(r, i + 1):r) {
         k <- k + 1
-        print(sprintf("  pi_1|%i - pi_1|%i: estimate = %6.4f (%6.4f to %6.4f)", i, j, differences[k], L[k], U[k]), quote = FALSE)
+        my_sprintf_cat("  pi_1|%i - pi_1|%i: estimate = %6.4f (%6.4f to %6.4f)\n", i, j, differences[k], L[k], U[k])
       }
     }
   }
-
-  invisible(list(L = L, U = U, differences = differences))
+  return(
+    contingencytables_result(
+      list(lower = L, upper = U, differences = differences),
+      printresults
+    )
+  )
 }
