@@ -3,33 +3,30 @@
 #' @description Described in Chapter 3 "The 1xc Table and the Multinomial Distribution"
 #' @param n the observed counts (a 1xc vector, where c is the number of categories)
 #' @param pi0 given probabilities (a 1xc vector)
-#' @param printresults display results (F = no, T = yes)
 #' @importFrom stats dmultinom
 #' @examples
 #' # Genotype counts for SNP rs 6498169 in RA patients
-#' \dontrun{
-#' Exact_multinomial_test_1xc(n = c(276, 380, 118), pi0 = c(0.402, 0.479, 0.119))
-#' }
+#' Exact_multinomial_test_1xc(n = snp6498169$complete$n, pi0 = snp6498169$complete$pi0)
+#'
 #' # subset of 10 patients
-#' Exact_multinomial_test_1xc(n = c(6, 1, 3), pi0 = c(0.402, 0.479, 0.119))
+#' Exact_multinomial_test_1xc(n = snp6498169$subset$n, pi0 = snp6498169$subset$pi0)
 #' @export
-#' @return probability value
-Exact_multinomial_test_1xc <- function(n, pi0, printresults = TRUE) {
+#' @return An object of the [contingencytables_result] class,
+#' basically a subclass of [base::list()]. Use the [utils::str()] function
+#' to see the specific elements returned.
+Exact_multinomial_test_1xc <- function(n, pi0) {
+  validateArguments(mget(ls()))
   c0 <- length(n)
   N <- sum(n)
 
   # Identify all possible tables with N observations (with 3,4,...,7 categories)
-  if (c0 == 3) {
-    x <- all.tables3(N)
-  } else if (c0 == 4) {
-    x <- all.tables4(N)
-  } else if (c0 == 5) {
-    x <- all.tables5(N)
-  } else if (c0 == 6) {
-    x <- all.tables6(N)
-  } else if (c0 == 7) {
-    x <- all.tables7(N)
-  }
+  x <- switch(
+    EXPR = c0,
+    stop("Please provide a sample of size 3 or larger"),
+    stop("Please provide a sample of size 3 or larger"),
+    all_tables_3(N), all_tables_4(N), all_tables_5(N), all_tables_6(N),
+    all_tables_7(N)
+  )
 
   P <- 0
   Tobs <- sum(((n - N * pi0)^2) / (N * pi0))
@@ -40,26 +37,14 @@ Exact_multinomial_test_1xc <- function(n, pi0, printresults = TRUE) {
     }
   }
 
-  if (printresults) {
-    print(sprintf("The exact multinomial test: P = %7.5f", P), quote = FALSE)
-  }
-
-  invisible(P)
+  res <- contingencytables_result(
+    list("P" = P), sprintf("The exact multinomial test: P = %7.5f", P)
+  )
+  return(res)
 }
 
 # =========================
-all.tables3 <- function(N) {
-  x <- vector()
-  for (x1 in 0:N) {
-    for (x2 in 0:(N - x1)) {
-      x <- rbind(x, c(x1, x2, N - x1 - x2))
-    }
-  }
-  return(x)
-}
-
-# =========================
-all.tables4 <- function(N) {
+all_tables_4 <- function(N) {
   x <- vector()
   for (x1 in (0:N)) {
     for (x2 in 0:(N - x1)) {
@@ -72,7 +57,7 @@ all.tables4 <- function(N) {
 }
 
 # =========================
-all.tables5 <- function(N) {
+all_tables_5 <- function(N) {
   x <- vector()
   for (x1 in 0:N) {
     for (x2 in 0:(N - x1)) {
@@ -86,7 +71,7 @@ all.tables5 <- function(N) {
 }
 
 # =========================
-all.tables6 <- function(N) {
+all_tables_6 <- function(N) {
   x <- vector()
   for (x1 in 0:N) {
     for (x2 in 0:(N - x1)) {
@@ -102,7 +87,7 @@ all.tables6 <- function(N) {
 }
 
 # =========================
-all.tables7 <- function(N) {
+all_tables_7 <- function(N) {
   x <- vector()
   for (x1 in 0:N) {
     for (x2 in 0:(N - x1)) {
