@@ -5,16 +5,11 @@
 #' @param gamma parameter for the Berger and Boos procedure (default=0.0001 gamma=0: no adj)
 #' @param statistic 'Pearson' (Suissa-Shuster test default), 'LR' (likelihood ratio),
 #'' unpooled' (unpooled Z), or 'Fisher' (Fisher-Boschloo test)
-#' @param printresults display results (F = no, T = yes)
 #' @examples
-#' n <- rbind(c(3, 1), c(1, 3)) # Example: A lady tasting a cup of tea
-#' Exact_unconditional_test_2x2(n)
-#' n <- rbind(c(7, 27), c(1, 33)) # Example: Perondi et al. (2004)
-#' Exact_unconditional_test_2x2(n)
-#' n <- rbind(c(9, 4), c(4, 10)) # Example: Lampasona et al. (2013)
-#' Exact_unconditional_test_2x2(n)
-#' n <- rbind(c(0, 16), c(15, 57)) # Example: Ritland et al. (2007)
-#' Exact_unconditional_test_2x2(n)
+#' Exact_unconditional_test_2x2(tea)
+#' Exact_unconditional_test_2x2(perondi_2004)
+#' Exact_unconditional_test_2x2(lampasona_2013)
+#' Exact_unconditional_test_2x2(ritland_2007)
 #' @export
 #' @note Somewhat crude code with maximization over a simple partition of the
 #' nuisance parameter space into 'num_pi_values' equally spaced values
@@ -26,9 +21,17 @@
 #' @importFrom graphics lines
 #' @importFrom stats dhyper
 #' @importFrom grDevices dev.new
-#' @return Fisher's exact test statistic
-Exact_unconditional_test_2x2 <- function(n, statistic = "Pearson", gamma = 0.0001,
-                                         printresults = TRUE) {
+#' @return An object of the [contingencytables_result] class,
+#' basically a subclass of [base::list()]. Use the [utils::str()] function
+#' to see the specific elements returned.
+Exact_unconditional_test_2x2 <- function(n, statistic = "Pearson", gamma = 0.0001) {
+  validateArguments(
+    x = mget(ls()),
+    types = list(
+      n = "counts", statistic = c("Pearson", "LR", "unpooled", "Fisher"),
+      gamma = "skip"
+    )
+  )
   # Partition the parameter space into 'num_pi_values' equally spaced values
   num_pi_values <- 1000
 
@@ -77,7 +80,7 @@ Exact_unconditional_test_2x2 <- function(n, statistic = "Pearson", gamma = 0.000
   } else {
     # Berger and Boos procedure
     # Use the Clopper-Pearson exact interval
-    res.cpe <- ClopperPearson_exact_CI_1x2(np1, N, gamma, printresults = FALSE)
+    res.cpe <- unlist(ClopperPearson_exact_CI_1x2(np1, N, gamma))
     pivalues <- seq(
       res.cpe["lower"], res.cpe["upper"],
       length = num_pi_values
@@ -117,19 +120,17 @@ Exact_unconditional_test_2x2 <- function(n, statistic = "Pearson", gamma = 0.000
     )
   }
 
-  if (printresults) {
-    if (statistic == "Pearson") {
-      print(sprintf("The Suissa-Shuster exact unconditional test: P = %7.5f", P), quote = FALSE)
-    } else if (statistic == "LR") {
-      print(sprintf("Exact unconditional test with the LR statistic: P = %7.5f", P), quote = FALSE)
-    } else if (statistic == "unpooled") {
-      print(sprintf("Exact unconditional test with the unpooled Z statistic: P = %7.5f", P), quote = FALSE)
-    } else if (statistic == "Fisher") {
-      print(sprintf("Fisher-Boschloo exact unconditional test: P = %7.5f", P), quote = FALSE)
-    }
+  if (statistic == "Pearson") {
+    txt <- "The Suissa-Shuster exact unconditional test: P = %7.5f"
+  } else if (statistic == "LR") {
+    txt <- "Exact unconditional test with the LR statistic: P = %7.5f"
+  } else if (statistic == "unpooled") {
+    txt <- "Exact unconditional test with the unpooled Z statistic: P = %7.5f"
+  } else if (statistic == "Fisher") {
+    txt <- "Fisher-Boschloo exact unconditional test: P = %7.5f"
   }
 
-  invisible(P)
+  return(contingencytables_result(list("P" = P), sprintf(txt, P)))
 }
 
 
@@ -183,7 +184,7 @@ test_statistic_exact_unconditional_test_2x2 <- function(x11, x12, x21, x22, stat
   } else if (statistic == "Fisher") {
     # Fisher's exact test as test statistic
     x <- matrix(c(x11, x12, x21, x22), nrow = 2, byrow = TRUE)
-    T0 <- -Fisher_exact_test_2x2(x, "hypergeometric", printresults = FALSE)
+    T0 <- -Fisher_exact_test_2x2(x, "hypergeometric")$P
   }
 
   return(T0)
