@@ -4,19 +4,18 @@
 #' @description Described in Chapter 4 "The 2x2 Table"
 #' @param n the observed counts (a 2x2 matrix)
 #' @param alpha the nominal level, e.g. 0.05 for 95% CIs
-#' @param printresults display results (FALSE = no, TRUE = yes)
 #' @examples
-#' # A case-control study of GADA exposure on IPEX syndrome
-#' # (Lampasona et al., 2013)
-#' n <- matrix(c(9, 4, 4, 10), nrow = 2, byrow = TRUE)
-#' MiettinenNurminen_asymptotic_score_CI_OR_2x2(n)
+#' # A case-control study of GADA exposure on IPEX syndrome (Lampasona et al., 2013)
+#' MiettinenNurminen_asymptotic_score_CI_OR_2x2(lampasona_2013)
 #' # The association between CHRNA4 genotype and XFS (Ritland et al., 2007)
-#' n <- matrix(c(0, 16, 15, 57), nrow = 2, byrow = TRUE)
-#' MiettinenNurminen_asymptotic_score_CI_OR_2x2(n)
+#' MiettinenNurminen_asymptotic_score_CI_OR_2x2(ritland_2007)
 #' @export
-#' @return A data frame containing lower, upper and point estimates of the statistic
-MiettinenNurminen_asymptotic_score_CI_OR_2x2 <- function(n, alpha = 0.05,
-                                                         printresults = TRUE) {
+#' @return An object of the [contingencytables_result] class,
+#' basically a subclass of [base::list()]. Use the [utils::str()] function
+#' to see the specific elements returned.
+MiettinenNurminen_asymptotic_score_CI_OR_2x2 <- function(n, alpha = 0.05) {
+  validateArguments(mget(ls()))
+
   n11 <- n[1, 1]
   n21 <- n[2, 1]
   n1p <- n[1, 1] + n[1, 2]
@@ -64,16 +63,13 @@ MiettinenNurminen_asymptotic_score_CI_OR_2x2 <- function(n, alpha = 0.05,
     )$root
   }
 
-  if (printresults) {
-    print(
+  return(
+    contingencytables_result(
+      list(lower = L, upper = U, estimate = estimate),
       sprintf(
         "Mietinen-Nurminen asymptotic score CI: estimate = %6.4f (%g%% CI %6.4f to %6.4f)",
         estimate, 100 * (1 - alpha), L, U
-      ),
-      quote = FALSE
+      )
     )
-  }
-
-  res <- data.frame(lower = L, upper = U, estimate = estimate)
-  invisible(res)
+  )
 }
