@@ -7,33 +7,22 @@
 #' @param a scores assigned to the rows
 #' @param b scores assigned to the columns
 #' @param alpha the nominal significance level, used to compute a 100(1-alpha) confidence interval
-#' @param printresults display results (FALSE = no, TRUE = yes)
 #' @examples
+#' set.seed(3509)
+#' Pearson_correlation_coefficient_rxc_bca(table_7.7, nboot = 800)
+#' Pearson_correlation_coefficient_rxc_bca(table_7.8, nboot = 200)
 #' \dontrun{
-#' # Colorectal cancer (Table 7.7)
-#' n <- rbind(
-#'   c(2, 4, 29, 19), c(7, 6, 116, 51), c(19, 27, 201, 76), c(18, 22, 133, 54)
-#' )
-#' Pearson_correlation_coefficient_rxc_bca(n)
-#'
-#' # Breast Tumor (Table 7.8)
-#' n <- matrix(
-#'   c(15, 35, 6, 9, 6, 2, 4, 2, 11, 11, 0, 0, 1, 10, 21),
-#'   ncol = 5, byrow = TRUE
-#' )
-#' Pearson_correlation_coefficient_rxc_bca(n)
-#'
-#' # Self-rated health (Table 7.9)
-#' n <- matrix(
-#'   c(2, 3, 3, 3, 2, 58, 98, 14, 8, 162, 949, 252, 4, 48, 373, 369),
-#'   ncol = 4, byrow = TRUE
-#' )
-#' Pearson_correlation_coefficient_rxc_bca(n)
+#'   Pearson_correlation_coefficient_rxc_bca(table_7.9)
 #' }
 #' @export
-#' @return A list containing the statistic and the confindence interval limits
-Pearson_correlation_coefficient_rxc_bca <- function(n, nboot = 1e4, a = seq_len(nrow(n)), b = seq_len(ncol(n)), alpha = 0.05,
-                                                    printresults = TRUE) {
+#' @return An object of the [contingencytables_result] class,
+#' basically a subclass of [base::list()]. Use the [utils::str()] function
+#' to see the specific elements returned.
+Pearson_correlation_coefficient_rxc_bca <- function(
+  n, nboot = 1e4, a = seq_len(nrow(n)), b = seq_len(ncol(n)), alpha = 0.05
+) {
+  validateArguments(mget(ls()))
+
   # If no scores are given, use equally spaced scores
   r <- nrow(n)
   c <- ncol(n)
@@ -55,7 +44,7 @@ Pearson_correlation_coefficient_rxc_bca <- function(n, nboot = 1e4, a = seq_len(
   }
 
   # The estimate
-  rP <- Pearson_correlation_coefficient_rxc(n, a, b, alpha, printresults = FALSE)$rP
+  rP <- Pearson_correlation_coefficient_rxc(n, a, b, alpha)$rP
 
   # The CI bootstrap sample
   dat <- data.frame(Y1 = Y1, Y2 = Y2)
@@ -64,11 +53,12 @@ Pearson_correlation_coefficient_rxc_bca <- function(n, nboot = 1e4, a = seq_len(
   L <- ans.ci$bca[4]
   U <- ans.ci$bca[5]
 
-  if (printresults) {
-    .print("The Pearson correlation w / BCa bootstrap CI: r = %7.4f (%g%% CI %7.4f to %7.4f)\n", rP, 100 * (1 - alpha), L, U)
-  }
-
-  invisible(list(rP = rP, L = L, U = U))
+  return(
+    contingencytables_result(
+      list(rP = rP, L = L, U = U),
+      sprintf("The Pearson correlation w / BCa bootstrap CI: r = %7.4f (%g%% CI %7.4f to %7.4f)", rP, 100 * (1 - alpha), L, U)
+    )
+  )
 }
 
 
@@ -86,10 +76,6 @@ f.Pccrb <- function(dat, indx, .param) {
   for (id in seq_along(Y1)) {
     n[Y1[id], Y2[id]] <- n[Y1[id], Y2[id]] + 1
   }
-  rP <- Pearson_correlation_coefficient_rxc(n, a, b, alpha, printresults = FALSE)$rP
+  rP <- Pearson_correlation_coefficient_rxc(n, a, b, alpha)$rP
   return(rP)
 }
-
-.print <- function(s, ...) {
-  print(sprintf(gsub("\n", "", s), ...), quote = FALSE)
-}
