@@ -4,19 +4,19 @@
 #' @param n the observed counts (a 2x2 matrix)
 #' @param a,b parameters of the beta distribution
 #' @param alpha the nominal level, e.g. 0.05 for 95# CIs
-#' @param printresults display results (0 = no, 1 = yes)
 #' @examples
 #' # An RCT of high vs standard dose of epinephrine (Perondi et al., 2004)
-#' n <- matrix(c(7, 27, 1, 33), nrow = 2, byrow = TRUE)
-#' PriceBonett_approximate_Bayes_CI_2x2(n)
+#' PriceBonett_approximate_Bayes_CI_2x2(perondi_2004)
 #'
 #' # The association between CHRNA4 genotype and XFS (Ritland et al., 2007)
-#' n <- matrix(c(0, 16, 15, 57), nrow = 2, byrow = TRUE)
-#' PriceBonett_approximate_Bayes_CI_2x2(n)
+#' PriceBonett_approximate_Bayes_CI_2x2(ritland_2007)
 #'
 #' @export
-#' @return A data frame containing lower, upper and point estimates of the statistic
-PriceBonett_approximate_Bayes_CI_2x2 <- function(n, a = 1.25, b = 2.5, alpha = 0.05, printresults = TRUE) {
+#' @return An object of the [contingencytables_result] class,
+#' basically a subclass of [base::list()]. Use the [utils::str()] function
+#' to see the specific elements returned.
+PriceBonett_approximate_Bayes_CI_2x2 <- function(n, a = 1.25, b = 2.5, alpha = 0.05) {
+  validateArguments(mget(ls()))
   n1p <- n[1, 1] + n[1, 2]
   n2p <- n[2, 1] + n[2, 2]
 
@@ -44,13 +44,13 @@ PriceBonett_approximate_Bayes_CI_2x2 <- function(n, a = 1.25, b = 2.5, alpha = 0
   L <- exp(log_phi_tilde - z * sqrt(var_log_phi_tilde))
   U <- exp(log_phi_tilde + z * sqrt(var_log_phi_tilde))
 
-  if (printresults) {
-    print(sprintf(
-      "The Price-Bonett approximate Bayes CI: estimate = %6.4f (%g%% CI %6.4f to %6.4f)",
-      estimate, 100 * (1 - alpha), L, U
-    ), quote = FALSE)
-  }
-
-  res <- data.frame(lower = L, upper = U, estimate = estimate)
-  invisible(res)
+  return(
+    contingencytables_result(
+      list(lower = L, upper = U, estimate = estimate),
+      sprintf(
+        "The Price-Bonett approximate Bayes CI: estimate = %6.4f (%g%% CI %6.4f to %6.4f)",
+        estimate, 100 * (1 - alpha), L, U
+      )
+    )
+  )
 }
