@@ -5,32 +5,20 @@
 #' @param n the observed table (an rxc matrix)
 #' @param nboot number of bootstrap samples
 #' @param alpha the nominal significance level, used to compute a 100(1-alpha) confidence interval
-#' @param printresults display results (FALSE = no, TRUE = yes)
 #' @examples
+#' set.seed(2921)
+#' Spearman_correlation_coefficient_rxc_bca(table_7.7, nboot = 800)
+#' Spearman_correlation_coefficient_rxc_bca(table_7.8, nboot = 200)
 #' \dontrun{
-#' # Colorectal cancer (Table 7.7)
-#' n <- rbind(
-#'   c(2, 4, 29, 19), c(7, 6, 116, 51), c(19, 27, 201, 76), c(18, 22, 133, 54)
-#' )
-#'
-#' Spearman_correlation_coefficient_rxc_bca(n)
-#' # Breast Tumor (Table 7.8)
-#' n <- matrix(
-#'   c(15, 35, 6, 9, 6, 2, 4, 2, 11, 11, 0, 0, 1, 10, 21),
-#'   ncol = 5, byrow = TRUE
-#' )
-#' Spearman_correlation_coefficient_rxc_bca(n)
-#'
-#' # Self-rated health (Table 7.9)
-#' n <- matrix(
-#'   c(2, 3, 3, 3, 2, 58, 98, 14, 8, 162, 949, 252, 4, 48, 373, 369),
-#'   ncol = 4, byrow = TRUE
-#' )
-#' Spearman_correlation_coefficient_rxc_bca(n)
+#'   Spearman_correlation_coefficient_rxc_bca(table_7.9)
 #' }
 #' @export
-#' @return A list containing the statistic and the confindence interval limits
-Spearman_correlation_coefficient_rxc_bca <- function(n, nboot = 10000, alpha = 0.05, printresults = TRUE) {
+#' @return An object of the [contingencytables_result] class,
+#' basically a subclass of [base::list()]. Use the [utils::str()] function
+#' to see the specific elements returned.
+Spearman_correlation_coefficient_rxc_bca <- function(n, nboot = 10000, alpha = 0.05) {
+  validateArguments(mget(ls()))
+
   r <- nrow(n)
   c <- ncol(n)
   N <- sum(n)
@@ -52,7 +40,7 @@ Spearman_correlation_coefficient_rxc_bca <- function(n, nboot = 10000, alpha = 0
   }
 
   # The estimate
-  rho <- Spearman_correlation_coefficient_rxc(n, alpha, printresults = FALSE)$rho
+  rho <- Spearman_correlation_coefficient_rxc(n, alpha)$rho
 
   # The CI bootstrap sample
   dat <- data.frame(Y1 = Y1, Y2 = Y2)
@@ -61,11 +49,12 @@ Spearman_correlation_coefficient_rxc_bca <- function(n, nboot = 10000, alpha = 0
   L <- ans.ci$bca[4]
   U <- ans.ci$bca[5]
 
-  if (printresults) {
-    .print("The Spearman correlation w / BCa bootstrap CI: rho = %7.4f (%g%% CI %7.4f to %7.4f)\n", rho, 100 * (1 - alpha), L, U)
-  }
-
-  invisible(list(rho = rho, L = L, U = U))
+  return(
+    contingencytables_result(
+      list(rho = rho, L = L, U = U),
+      sprintf("The Spearman correlation w / BCa bootstrap CI: rho = %7.4f (%g%% CI %7.4f to %7.4f)", rho, 100 * (1 - alpha), L, U)
+    )
+  )
 }
 
 
@@ -81,10 +70,6 @@ f.Sccrb <- function(dat, indx, .param) {
   for (id in seq_along(Y1)) {
     n[Y1[id], Y2[id]] <- n[Y1[id], Y2[id]] + 1
   }
-  rho <- Spearman_correlation_coefficient_rxc(n, alpha, printresults = FALSE)$rho
+  rho <- Spearman_correlation_coefficient_rxc(n, alpha)$rho
   return(rho)
 }
-
-.print <- function(s, ...) {
-  print(sprintf(gsub("\n", "", s), ...), quote = FALSE)
-}
