@@ -10,31 +10,29 @@
 #' @param n the observed counts (an rx2 matrix)
 #' @param a scores assigned to the rows
 #' @param alpha the nominal level, e.g. 0.05 for 95% CIs
-#' @param printresults display results (0 = no, 1 = yes)
 #' @param linkfunction Link function for the binomial distribution see
 #' \code{?family} for more details
 #' @examples
 #' # Alcohol consumption and malformations (Mills and Graubard, 1987)
-#' n <- matrix(
-#'   c(48, 17066, 38, 14464, 5, 788, 1, 126, 1, 37),
-#'   ncol = 2,
-#'   byrow = TRUE
-#' )
-#' n <- rbind(c(48, 17066), c(38, 14464), c(5, 788), c(1, 126), c(1, 37)) # same as before
-#' a <- c(1, 2, 3, 4, 5)
-#' Trend_estimate_CI_tests_rx2(n, a)
+#' Trend_estimate_CI_tests_rx2(mills_graubard_1987, 1:5)
 #'
 #' # levated troponin T levels in stroke patients (Indredavik et al., 2008)
-#' n <- rbind(c(8, 53), c(10, 48), c(11, 100), c(22, 102), c(6, 129))
-#' a <- c(1, 2, 3, 4, 5)
-#' Trend_estimate_CI_tests_rx2(n, a)
+#' Trend_estimate_CI_tests_rx2(indredavik_2008, 1:5)
 #' @export
-#' @return A list containing several test statistics (see description above).
-Trend_estimate_CI_tests_rx2 <- function(n, a, linkfunction = "logit", alpha = 0.05, printresults = TRUE) {
+#' @return An object of the [contingencytables_result] class,
+#' basically a subclass of [base::list()]. Use the [utils::str()] function
+#' to see the specific elements returned.
+Trend_estimate_CI_tests_rx2 <- function(
+  n, a, linkfunction = "logit", alpha = 0.05
+) {
+  validateArguments(mget(ls()))
+
   nip <- apply(n, 1, sum)
 
   # Fit model and get estimat of the trend (beta) and its standard error
-  mdl1 <- glm(cbind(n[, 1], n[, 2]) ~ 1 + a, family = binomial(link = linkfunction))
+  mdl1 <- glm(
+    cbind(n[, 1], n[, 2]) ~ 1 + a, family = binomial(link = linkfunction)
+  )
   L1 <- -mdl1$deviance / 2
   betahat <- mdl1$coefficients[2]
   SEhat <- summary(mdl1)$coefficients[2, 2]
@@ -79,7 +77,8 @@ Trend_estimate_CI_tests_rx2 <- function(n, a, linkfunction = "logit", alpha = 0.
     P_D <- 1 - pchisq(D, df_D)
   }
 
-  # Output arguments (estimated trend, observed statistics, degrees of freedom, P-values, and CI)
+  # Output arguments (estimated trend, observed statistics, degrees of freedom,
+  # P-values, and CI)
   results <- list()
   results$betahat <- betahat
 
@@ -102,13 +101,30 @@ Trend_estimate_CI_tests_rx2 <- function(n, a, linkfunction = "logit", alpha = 0.
   results$CI_Wald_width <- CI_Wald[2] - CI_Wald[1]
 
 
-  if (printresults) {
-    print(sprintf("Wald test:                    P = %7.5f, T = %5.3f", P_Wald, Z_Wald), quote = FALSE)
-    print(sprintf("Likelihood ratio test:        P = %7.5f, T = %5.3f (df = %i)", P_LR, T_LR, df_LR), quote = FALSE)
-    print(sprintf("Pearson goodness-of-fit test: P = %7.5f, T = %5.3f (df = %i)", P_chi2, chi2, df_chi2), quote = FALSE)
-    print(sprintf("LR (deviance) test:           P = %7.5f, T = %5.3f (df = %i)", P_D, D, df_D), quote = FALSE)
-    print(sprintf("Trend estimate and Wald CI:   betahat = %6.4f (%g%% CI %6.4f to %6.4f)", betahat, 100 * (1 - alpha), CI_Wald[1], CI_Wald[2]), quote = FALSE)
+  printresults <- function() {
+    my_sprintf_cat(
+        "Wald test:                    P = %7.5f, T = %5.3f\n", P_Wald, Z_Wald
+    )
+    my_sprintf_cat(
+        "Likelihood ratio test:        P = %7.5f, T = %5.3f (df = %i)\n",
+        P_LR, T_LR, df_LR
+    )
+    my_sprintf_cat(
+        "Pearson goodness-of-fit test: P = %7.5f, T = %5.3f (df = %i)\n",
+        P_chi2, chi2, df_chi2
+    )
+    my_sprintf_cat(
+        "LR (deviance) test:           P = %7.5f, T = %5.3f (df = %i)\n",
+        P_D, D, df_D
+    )
+    my_sprintf_cat(
+      paste(
+        "Trend estimate and Wald CI:   betahat =",
+        "%6.4f (%g%% CI %6.4f to %6.4f)"
+      ),
+      betahat, 100 * (1 - alpha), CI_Wald[1], CI_Wald[2]
+    )
   }
 
-  invisible(results)
+  return(contingencytables_result(results, printresults))
 }
