@@ -1,23 +1,26 @@
-#' @title The uncorrected asymptotic score confidence interval for the odds ratio
-#' @description The uncorrected asymptotic score confidence interval for the odds ratio
+#' @title The uncorrected asymptotic score confidence interval for the odds
+#' ratio
+#' @description The uncorrected asymptotic score confidence interval for the
+#' odds ratio
 #' @description Described in Chapter 4 "The 2x2 Table"
 #' @param n the observed counts (a 2x2 matrix)
 #' @param alpha the nominal level, e.g. 0.05 for 95% CIs
-#' @param printresults display results (FALSE = no, TRUE = yes)
 #' @examples
-#' # A case-control study of GADA exposure on IPEX syndrome (Lampasona et al., 2013):
-#' n <- matrix(c(9, 4, 4, 10), nrow = 2, byrow = TRUE)
-#' Uncorrected_asymptotic_score_CI_2x2(n)
+#' # A case-control study of GADA exposure on IPEX syndrome
+#' # (Lampasona et al., 2013):
+#' Uncorrected_asymptotic_score_CI_2x2(lampasona_2013)
 #'
 #' # The association between CHRNA4 genotype and XFS (Ritland et al., 2007):
-#' n <- matrix(c(0, 16, 15, 57), nrow = 2, byrow = TRUE)
-#' Uncorrected_asymptotic_score_CI_2x2(n)
+#' Uncorrected_asymptotic_score_CI_2x2(ritland_2007)
 #'
 #' @export
-#' @return A data frame containing lower, upper and point estimates of the statistic
-Uncorrected_asymptotic_score_CI_2x2 <- function(n, alpha = 0.05, printresults = TRUE) {
-  # global n11 n21 n1p n2p alphaglobal limit
+#' @return An object of the [contingencytables_result] class,
+#' basically a subclass of [base::list()]. Use the [utils::str()] function
+#' to see the specific elements returned.
+Uncorrected_asymptotic_score_CI_2x2 <- function(n, alpha = 0.05) {
+  validateArguments(mget(ls()))
 
+  # global n11 n21 n1p n2p alphaglobal limit
   n11 <- n[1, 1]
   n21 <- n[2, 1]
   n1p <- n[1, 1] + n[1, 2]
@@ -61,13 +64,16 @@ Uncorrected_asymptotic_score_CI_2x2 <- function(n, alpha = 0.05, printresults =
     )$root
   }
 
-  if (printresults) {
-    print(sprintf(
-      "Uncorrected asymptotic score CI: estimate = %6.4f (%g%% CI %6.4f to %6.4f)",
+  printresults <- function() {
+    sprintf(
+      paste(
+        "Uncorrected asymptotic score CI: estimate =",
+        "%6.4f (%g%% CI %6.4f to %6.4f)"
+      ),
       estimate, 100 * (1 - alpha), L, U
-    ), quote = FALSE)
+    )
   }
 
-  res <- data.frame(lower = L, upper = U, estimate = estimate)
-  invisible(res)
+  res <- list(lower = L, upper = U, estimate = estimate)
+  return(contingencytables_result(res, printresults))
 }
