@@ -5,22 +5,24 @@
 #' @param X the number of successes
 #' @param n the total number of observations
 #' @param alpha the nominal level, e.g. 0.05 for 95# CIs
-#' @param printresults display results (0 = no, 1 = yes)
 #' @examples
 #' # The number of 1st order male births (Singh et al. 2010)
-#' Wald_CI_CC_1x2(X = 250, n = 533)
+#' Wald_CI_CC_1x2(singh_2010["1st", "X"], singh_2010["1st", "n"])
 #' # The number of 2nd order male births (Singh et al. 2010)
-#' Wald_CI_CC_1x2(X = 204, n = 412)
+#' Wald_CI_CC_1x2(singh_2010["2nd", "X"], singh_2010["2nd", "n"])
 #' # The number of 3rd order male births (Singh et al. 2010)
-#' Wald_CI_CC_1x2(X = 103, n = 167)
+#' Wald_CI_CC_1x2(singh_2010["3rd", "X"], singh_2010["3rd", "n"])
 #' # The number of 4th order male births (Singh et al. 2010)
-#' Wald_CI_CC_1x2(X = 33, n = 45)
+#' with(singh_2010["4th", ], Wald_CI_CC_1x2(X, n)) # alternative syntax
 #' # Ligarden et al. (2010)
-#' Wald_CI_CC_1x2(X = 13, n = 16)
+#' Wald_CI_CC_1x2(ligarden_2010["X"], ligarden_2010["n"])
 #'
 #' @export
-#' @return A vector containing lower, upper and point estimates of the statistic
-Wald_CI_CC_1x2 <- function(X, n, alpha = 0.05, printresults = TRUE) {
+#' @return An object of the [contingencytables_result] class,
+#' basically a subclass of [base::list()]. Use the [utils::str()] function
+#' to see the specific elements returned.
+Wald_CI_CC_1x2 <- function(X, n, alpha = 0.05) {
+  validateArguments(mget(ls()))
 
   # Estimate of the binomial probability (pihat)
   estimate <- X / n
@@ -39,16 +41,17 @@ Wald_CI_CC_1x2 <- function(X, n, alpha = 0.05, printresults = TRUE) {
   L <- max(0, L)
   U <- min(U, 1)
 
-  if (printresults) {
-    print(
-      sprintf(
-        "The Wald CI with continuity correction: estimate = %6.4f (%g%% CI %6.4f to %6.4f)",
-        estimate, 100 * (1 - alpha), L, U
-      )
+  printresults <- function() {
+    sprintf(
+      paste(
+        "The Wald CI with continuity correction: estimate =",
+        "%6.4f (%g%% CI %6.4f to %6.4f)"
+      ),
+      estimate, 100 * (1 - alpha), L, U
     )
   }
 
-  res <- c(L, U, estimate)
+  res <- list(L, U, estimate)
   names(res) <- c("lower", "upper", "estimate")
-  invisible(res)
+  return(contingencytables_result(res, printresults))
 }
